#!/system/bin/sh
MODDIR=${0%/*}
# Function to set GPU block boost
set_gpu_block_boost() {
  # Set GPU Block Boost level
  write /sys/kernel/ged/hal/gpu_boost_level 101
}

# Function to apply high temperature settings
apply_high_temp_settings() {
  # Set CPU scaling governor to performance and lock max CPU frequency to 2.2 GHz
  write /sys/devices/system/cpu/cpu0/cpufreq/scaling_governor performance
  write /sys/devices/system/cpu/cpu1/cpufreq/scaling_governor performance
  write /sys/devices/system/cpu/cpu2/cpufreq/scaling_governor performance
  write /sys/devices/system/cpu/cpu3/cpufreq/scaling_governor performance

  # Lock CPU max frequency to 2.2 GHz
  write /sys/devices/system/cpu/cpu0/cpufreq/scaling_max_freq 2200000000 # 2.2 GHz in Hz
  write /sys/devices/system/cpu/cpu1/cpufreq/scaling_max_freq 2200000000
  write /sys/devices/system/cpu/cpu2/cpufreq/scaling_max_freq 2200000000
  write /sys/devices/system/cpu/cpu3/cpufreq/scaling_max_freq 2200000000

  # Additional CPU settings
  write /sys/devices/system/cpu/cpufreq/policy0/scaling_governor performance
  write /sys/devices/system/cpu/cpufreq/policy4/scaling_governor performance
  write /sys/devices/system/cpu/cpufreq/performance/above_hispeed_delay 0
  write /sys/devices/system/cpu/cpufreq/performance/boost 1
  write /sys/devices/system/cpu/cpufreq/performance/go_hispeed_load 75
  write /sys/devices/system/cpu/cpufreq/performance/max_freq_hysteresis 1
  write /sys/devices/system/cpu/cpufreq/performance/align_windows 1

  # fpsgo Ultimate speed
  write /system/sys/kernel/fpsgo/common/fpsgo_enable
  
  # Set Ged Boost Gpu Performance 
  set_gpu_block_boost
  
  # Set GPU governor to performance
  write /sys/class/misc/mali_ctrl/gpu_governor performance
  
  # Lock Gpu Target
  echo "00" > /proc/gpufreqv2/fix_target_opp_index

  # Lock GPU Mali frequency to 1400 MHz
  write /sys/class/misc/mali_ctrl/max_gpuclk 1400000000 # 1100 MHz in Hz

  # Additional settings for performance boost
  write /sys/module/mali_idler/parameters/mali_idler_active 0
  write /sys/module/lazyplug/parameters/nr_possible_cores 8
  write /sys/module/msm_performance/parameters/touchboost 1

  # Set CPU core affinity for foreground and top-app
  write /dev/cpuset/foreground/boost/cpus 4-7
  write /dev/cpuset/foreground/cpus 0-3,4-7
  write /dev/cpuset/top-app/cpus 0-7

  # Set graphics settings for gaming
  # Example: Enable anti-aliasing and texture filtering
  write /sys/class/misc/mali0/aa_enable 1
  write /sys/class/misc/mali0/af_enable 1

  # Fast lock for all games to achieve stable 90fps
  write /sys/class/misc/mali_ctrl/max_gpuclk 500000000

  # Set screen refresh rate to 240Hz
  # Note: Replace the following command with the appropriate command for your device
  # Example command (may vary depending on your device):
  # write /sys/class/graphics/fb0/mode 1920x1080p240

####################################
# Stune Boost
####################################
for stune in /dev/stune; do
    echo "0" > "$stune/background/schedtune.boost"
    echo "0" > "$stune/background/schedtune.colocate"
    echo "0" > "$stune/background/schedtune.prefer_idle"
    echo "0" > "$stune/background/schedtune.sched_boost"
    echo "1" > "$stune/background/schedtune.sched_boost_no_override"
    echo "0" > "$stune/background/schedtune.prefer_perf"
    echo "0" > "$stune/background/schedtune.util_est_en"
    echo "0" > "$stune/background/schedtune.ontime_en"
    echo "0" > "$stune/background/schedtune.prefer_high_cap"
    
    # Penyesuaian tambahan terhadap stune
    echo "0" > "$stune/foreground/schedtune.boost"
    echo "0" > "$stune/foreground/schedtune.colocate"
    echo "1" > "$stune/foreground/schedtune.prefer_idle"
    echo "0" > "$stune/foreground/schedtune.sched_boost"
    echo "1" > "$stune/foreground/schedtune.sched_boost_no_override"
    echo "0" > "$stune/foreground/schedtune.prefer_perf"
    echo "0" > "$stune/foreground/schedtune.util_est_en"
    echo "0" > "$stune/foreground/schedtune.ontime_en"
    echo "0" > "$stune/foreground/schedtune.prefer_high_cap"
    
    # Tambahan penyesuaian stune untuk modul lainnya
    echo "0" > "$stune/nnapi-hal/schedtune.boost"
    echo "0" > "$stune/nnapi-hal/schedtune.colocate"
    echo "1" > "$stune/nnapi-hal/schedtune.prefer_idle"
    echo "0" > "$stune/nnapi-hal/schedtune.sched_boost"
    echo "1" > "$stune/nnapi-hal/schedtune.sched_boost_no_override"
    echo "0" > "$stune/nnapi-hal/schedtune.prefer_perf"
    echo "0" > "$stune/nnapi-hal/schedtune.util_est_en"
    echo "0" > "$stune/nnapi-hal/schedtune.ontime_en"
    echo "0" > "$stune/nnapi-hal/schedtune.prefer_high_cap"
    
    # Penyesuaian tambahan stune
    echo "0" > "$stune/rt/schedtune.boost"
    echo "0" > "$stune/rt/schedtune.colocate"
    echo "0" > "$stune/rt/schedtune.prefer_idle"
    echo "0" > "$stune/rt/schedtune.sched_boost"
    echo "1" > "$stune/rt/schedtune.sched_boost_no_override"
    echo "0" > "$stune/rt/schedtune.prefer_perf"
    echo "0" > "$stune/rt/schedtune.util_est_en"
    echo "0" > "$stune/rt/schedtune.ontime_en"
    echo "0" > "$stune/rt/schedtune.prefer_high_cap"
    
    # Penyesuaian stune untuk kamera
    echo "0" > "$stune/camera-daemon/schedtune.boost"
    echo "0" > "$stune/camera-daemon/schedtune.colocate"
    echo "1" > "$stune/camera-daemon/schedtune.prefer_idle"
    echo "0" > "$stune/camera-daemon/schedtune.sched_boost"
    echo "1" > "$stune/camera-daemon/schedtune.sched_boost_no_override"
    echo
